@@ -21,7 +21,7 @@
 
 #include <R.h>
 #include <Rinternals.h>
-#include "git2.h"
+#include <git2.h>
 
 SEXP git2r_branch_canonical_name(SEXP branch);
 SEXP git2r_branch_create(SEXP branch_name, SEXP commit, SEXP force);
