@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2018 The git2r contributors
+## Copyright (C) 2013-2019 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -76,6 +76,7 @@ stopifnot(identical(r$committer$name, "Alice"))
 stopifnot(identical(r$committer$email, "alice@example.org"))
 stopifnot(identical(r$refname, "refs/remotes/origin/master"))
 stopifnot(identical(r$repo$path, repo$path))
+push(branches(repo)[[1]])
 
 ## Check result in bare repository
 stopifnot(identical(length(commits(bare_repo)), 1L))
@@ -101,6 +102,13 @@ stopifnot(identical(commit_2$summary, bare_commit_2$summary))
 stopifnot(identical(commit_2$message, bare_commit_2$message))
 stopifnot(!identical(commit_2$repo, bare_commit_2$repo))
 
+## Check 'set_upstream'
+branch_set_upstream(repository_head(repo), NULL)
+push(repo, "origin", "refs/heads/master")
+stopifnot(is.null(branch_get_upstream(repository_head(repo))))
+push(repo, "origin", "refs/heads/master", set_upstream = TRUE)
+stopifnot(!is.null(branch_get_upstream(repository_head(repo))))
+
 ## Cleanup
 unlink(path_bare, recursive=TRUE)
 unlink(path_repo, recursive=TRUE)
